==> monaco-vscode-user-data-profile-service-override-12.0.0.tgz: package/index.js <==

import { __decorate, __param } from 'vscode/external/tslib/tslib.es6';
import { SyncDescriptor } from 'vscode/vscode/vs/platform/instantiation/common/descriptors';
import { IUserDataSyncStoreManagementService, IUserDataSyncUtilService } from 'vscode/vscode/vs/platform/userDataSync/common/userDataSync.service';
import { BrowserUserDataProfilesService } from './vscode/src/vs/platform/userDataProfile/browser/userDataProfile.js';
import { IUserDataProfilesService } from 'vscode/vscode/vs/platform/userDataProfile/common/userDataProfile.service';
import { UserDataInitializationService } from './vscode/src/vs/workbench/services/userData/browser/userDataInit.js';
import { IUserDataInitializationService } from 'vscode/vscode/vs/workbench/services/userData/browser/userDataInit.service';
import { UserDataSyncInitializer } from './vscode/src/vs/workbench/services/userDataSync/browser/userDataSyncInit.js';
import { UserDataProfileInitializer } from './vscode/src/vs/workbench/services/userDataProfile/browser/userDataProfileInit.js';
import { IBrowserWorkbenchEnvironmentService } from 'vscode/vscode/vs/workbench/services/environment/browser/environmentService.service';
import { ISecretStorageService } from 'vscode/vscode/vs/platform/secrets/common/secrets.service';
import { IFileService } from 'vscode/vscode/vs/platform/files/common/files.service';
import { IStorageService } from 'vscode/vscode/vs/platform/storage/common/storage.service';
import { IProductService } from 'vscode/vscode/vs/platform/product/common/productService.service';
import { IRequestService } from 'vscode/vscode/vs/platform/request/common/request.service';
import { ILogService } from 'vscode/vscode/vs/platform/log/common/log.service';
import { IUriIdentityService } from 'vscode/vscode/vs/platform/uriIdentity/common/uriIdentity.service';
import { IUserDataProfileService, IUserDataProfileImportExportService, IUserDataProfileManagementService } from 'vscode/vscode/vs/workbench/services/userDataProfile/common/userDataProfile.service';
import { mark } from 'vscode/vscode/vs/base/common/performance';
import { timeout } from 'vscode/vscode/vs/base/common/async';
import { IWorkbenchConfigurationService } from '@codingame/monaco-vscode-422642f2-7e3a-5c1c-9e1e-1d3ef1817346-common/vscode/vs/workbench/services/configuration/common/configuration.service';
import { UserDataProfileImportExportService } from './vscode/src/vs/workbench/services/userDataProfile/browser/userDataProfileImportExportService.js';
import { UserDataProfileManagementService } from './vscode/src/vs/workbench/services/userDataProfile/browser/userDataProfileManagement.js';
import { IUserDataProfileStorageService } from 'vscode/vscode/vs/platform/userDataProfile/common/userDataProfileStorageService.service';
import { UserDataProfileStorageService } from './vscode/src/vs/workbench/services/userDataProfile/browser/userDataProfileStorageService.js';
import { UserDataProfileService } from 'vscode/vscode/vs/workbench/services/userDataProfile/common/userDataProfileService';
import { UserDataSyncUtilService } from './vscode/src/vs/workbench/services/userDataSync/common/userDataSyncUtil.js';
import { registerServiceInitializePostParticipant } from 'vscode/lifecycle';
import { getWorkspaceIdentifier } from 'vscode/workbench';
import './vscode/src/vs/workbench/contrib/userDataProfile/browser/userDataProfile.contribution.js';

function isWorkspaceService(configurationService) {
    return 'reloadLocalUserConfiguration' in configurationService;
}
async function initializeUserData(userDataInitializationService, configurationService) {
    if (await userDataInitializationService.requiresInitialization()) {
        mark('code/willInitRequiredUserData');
        await userDataInitializationService.initializeRequiredResources();
        if (isWorkspaceService(configurationService)) {
            await configurationService.reloadLocalUserConfiguration();
        }
        mark('code/didInitRequiredUserData');
    }
}
registerServiceInitializePostParticipant(async (accessor) => {
    try {
        await Promise.race([
            timeout(5000),
            initializeUserData(accessor.get(IUserDataInitializationService), accessor.get(IWorkbenchConfigurationService))
        ]);
    }
    catch (error) {
        accessor.get(ILogService).error(error);
    }
});
let InjectedUserDataInitializationService = class InjectedUserDataInitializationService extends UserDataInitializationService {
    constructor(environmentService, secretStorageService, userDataSyncStoreManagementService, fileService, userDataProfilesService, storageService, productService, requestService, logService, uriIdentityService, userDataProfileService) {
        const userDataInitializers = [];
        userDataInitializers.push(new UserDataSyncInitializer(environmentService, secretStorageService, userDataSyncStoreManagementService, fileService, userDataProfilesService, storageService, productService, requestService, logService, uriIdentityService));
        if (environmentService.options?.profile != null) {
            userDataInitializers.push(new UserDataProfileInitializer(environmentService, fileService, userDataProfileService, storageService, logService, uriIdentityService, requestService));
        }
        super(userDataInitializers);
    }
};
InjectedUserDataInitializationService = __decorate([
    __param(0, IBrowserWorkbenchEnvironmentService),
    __param(1, ISecretStorageService),
    __param(2, IUserDataSyncStoreManagementService),
    __param(3, IFileService),
    __param(4, IUserDataProfilesService),
    __param(5, IStorageService),
    __param(6, IProductService),
    __param(7, IRequestService),
    __param(8, ILogService),
    __param(9, IUriIdentityService),
    __param(10, IUserDataProfileService)
], InjectedUserDataInitializationService);
function getCurrentProfile(workspace, userDataProfilesService, environmentService) {
    if (environmentService.options?.profile != null) {
        const profile = userDataProfilesService.profiles.find((p) => p.name === environmentService.options?.profile?.name);
        if (profile != null) {
            return profile;
        }
        return userDataProfilesService.defaultProfile;
    }
    return (userDataProfilesService.getProfileForWorkspace(workspace) ??
        userDataProfilesService.defaultProfile);
}
let InjectedUserDataProfileService = class InjectedUserDataProfileService extends UserDataProfileService {
    constructor(environmentService, userDataProfilesService, logService) {
        const workspace = getWorkspaceIdentifier();
        const profile = getCurrentProfile(workspace, userDataProfilesService, environmentService);
        super(profile);
        if (profile === userDataProfilesService.defaultProfile &&
            environmentService.options?.profile != null) {
            userDataProfilesService
                .createNamedProfile(environmentService.options.profile.name, undefined, workspace)
                .then(async (profile) => {
                await this.updateCurrentProfile(profile);
            })
                .catch((err) => {
                logService.error(err);
            });
        }
    }
};
InjectedUserDataProfileService = __decorate([
    __param(0, IBrowserWorkbenchEnvironmentService),
    __param(1, IUserDataProfilesService),
    __param(2, ILogService)
], InjectedUserDataProfileService);
function getServiceOverride() {
    return {
        [IUserDataProfileService.toString()]: new SyncDescriptor(InjectedUserDataProfileService, [], true),
        [IUserDataProfilesService.toString()]: new SyncDescriptor(BrowserUserDataProfilesService, [], true),
        [IUserDataInitializationService.toString()]: new SyncDescriptor(InjectedUserDataInitializationService, [], true),
        [IUserDataProfileImportExportService.toString()]: new SyncDescriptor(UserDataProfileImportExportService, [], true),
        [IUserDataProfileManagementService.toString()]: new SyncDescriptor(UserDataProfileManagementService, [], true),
        [IUserDataProfileStorageService.toString()]: new SyncDescriptor(UserDataProfileStorageService, [], true),
        [IUserDataSyncUtilService.toString()]: new SyncDescriptor(UserDataSyncUtilService, [], true)
    };
}

export { getServiceOverride as default };

==> monaco-vscode-user-data-profile-service-override-13.1.0.tgz: package/index.js <==

import { __decorate, __param } from '@codingame/monaco-vscode-api/external/tslib/tslib.es6';
import { SyncDescriptor } from '@codingame/monaco-vscode-api/vscode/vs/platform/instantiation/common/descriptors';
import { IUserDataSyncStoreManagementService, IUserDataSyncUtilService } from '@codingame/monaco-vscode-api/vscode/vs/platform/userDataSync/common/userDataSync.service';
import { BrowserUserDataProfilesService } from './vscode/src/vs/platform/userDataProfile/browser/userDataProfile.js';
import { IUserDataProfilesService } from '@codingame/monaco-vscode-api/vscode/vs/platform/userDataProfile/common/userDataProfile.service';
import { UserDataInitializationService } from './vscode/src/vs/workbench/services/userData/browser/userDataInit.js';
import { IUserDataInitializationService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/userData/browser/userDataInit.service';
import { UserDataSyncInitializer } from './vscode/src/vs/workbench/services/userDataSync/browser/userDataSyncInit.js';
import { UserDataProfileInitializer } from './vscode/src/vs/workbench/services/userDataProfile/browser/userDataProfileInit.js';
import { IBrowserWorkbenchEnvironmentService } from '@codingame/monaco-vscode-411e0589-fa79-504b-b32c-80a88847b23a-common/vscode/vs/workbench/services/environment/browser/environmentService.service';
import { ISecretStorageService } from '@codingame/monaco-vscode-api/vscode/vs/platform/secrets/common/secrets.service';
import { IFileService } from '@codingame/monaco-vscode-api/vscode/vs/platform/files/common/files.service';
import { IStorageService } from '@codingame/monaco-vscode-api/vscode/vs/platform/storage/common/storage.service';
import { IProductService } from '@codingame/monaco-vscode-api/vscode/vs/platform/product/common/productService.service';
import { IRequestService } from '@codingame/monaco-vscode-api/vscode/vs/platform/request/common/request.service';
import { ILogService } from '@codingame/monaco-vscode-api/vscode/vs/platform/log/common/log.service';
import { IUriIdentityService } from '@codingame/monaco-vscode-api/vscode/vs/platform/uriIdentity/common/uriIdentity.service';
import { IUserDataProfileService, IUserDataProfileImportExportService, IUserDataProfileManagementService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/userDataProfile/common/userDataProfile.service';
import { mark } from '@codingame/monaco-vscode-api/vscode/vs/base/common/performance';
import { timeout } from '@codingame/monaco-vscode-api/vscode/vs/base/common/async';
import { IWorkbenchConfigurationService } from '@codingame/monaco-vscode-422642f2-7e3a-5c1c-9e1e-1d3ef1817346-common/vscode/vs/workbench/services/configuration/common/configuration.service';
import { UserDataProfileImportExportService } from './vscode/src/vs/workbench/services/userDataProfile/browser/userDataProfileImportExportService.js';
import { UserDataProfileManagementService } from './vscode/src/vs/workbench/services/userDataProfile/browser/userDataProfileManagement.js';
import { IUserDataProfileStorageService } from '@codingame/monaco-vscode-api/vscode/vs/platform/userDataProfile/common/userDataProfileStorageService.service';
import { UserDataProfileStorageService } from './vscode/src/vs/workbench/services/userDataProfile/browser/userDataProfileStorageService.js';
import { UserDataProfileService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/userDataProfile/common/userDataProfileService';
import { UserDataSyncUtilService } from './vscode/src/vs/workbench/services/userDataSync/common/userDataSyncUtil.js';
import { registerServiceInitializePostParticipant } from '@codingame/monaco-vscode-api/lifecycle';
import { getWorkspaceIdentifier } from '@codingame/monaco-vscode-api/workbench';
import './vscode/src/vs/workbench/contrib/userDataProfile/browser/userDataProfile.contribution.js';

function isWorkspaceService(configurationService) {
    return 'reloadLocalUserConfiguration' in configurationService;
}
async function initializeUserData(userDataInitializationService, configurationService) {
    if (await userDataInitializationService.requiresInitialization()) {
        mark('code/willInitRequiredUserData');
        await userDataInitializationService.initializeRequiredResources();
        if (isWorkspaceService(configurationService)) {
            await configurationService.reloadLocalUserConfiguration();
        }
        mark('code/didInitRequiredUserData');
    }
}
registerServiceInitializePostParticipant(async (accessor) => {
    try {
        await Promise.race([
            timeout(5000),
            initializeUserData(accessor.get(IUserDataInitializationService), accessor.get(IWorkbenchConfigurationService))
        ]);
    }
    catch (error) {
        accessor.get(ILogService).error(error);
    }
});
let InjectedUserDataInitializationService = class InjectedUserDataInitializationService extends UserDataInitializationService {
    constructor(environmentService, secretStorageService, userDataSyncStoreManagementService, fileService, userDataProfilesService, storageService, productService, requestService, logService, uriIdentityService, userDataProfileService) {
        const userDataInitializers = [];
        userDataInitializers.push(new UserDataSyncInitializer(environmentService, secretStorageService, userDataSyncStoreManagementService, fileService, userDataProfilesService, storageService, productService, requestService, logService, uriIdentityService));
        if (environmentService.options?.profile != null) {
            userDataInitializers.push(new UserDataProfileInitializer(environmentService, fileService, userDataProfileService, storageService, logService, uriIdentityService, requestService));
        }
        super(userDataInitializers);
    }
};
InjectedUserDataInitializationService = __decorate([
    __param(0, IBrowserWorkbenchEnvironmentService),
    __param(1, ISecretStorageService),
    __param(2, IUserDataSyncStoreManagementService),
    __param(3, IFileService),
    __param(4, IUserDataProfilesService),
    __param(5, IStorageService),
    __param(6, IProductService),
    __param(7, IRequestService),
    __param(8, ILogService),
    __param(9, IUriIdentityService),
    __param(10, IUserDataProfileService)
], InjectedUserDataInitializationService);
function getCurrentProfile(workspace, userDataProfilesService, environmentService) {
    if (environmentService.options?.profile != null) {
        const profile = userDataProfilesService.profiles.find((p) => p.name === environmentService.options?.profile?.name);
        if (profile != null) {
            return profile;
        }
        return userDataProfilesService.defaultProfile;
    }
    return (userDataProfilesService.getProfileForWorkspace(workspace) ??
        userDataProfilesService.defaultProfile);
}
let InjectedUserDataProfileService = class InjectedUserDataProfileService extends UserDataProfileService {
    constructor(environmentService, userDataProfilesService, logService) {
        const workspace = getWorkspaceIdentifier();
        const profile = getCurrentProfile(workspace, userDataProfilesService, environmentService);
        super(profile);
        if (profile === userDataProfilesService.defaultProfile &&
            environmentService.options?.profile != null) {
            userDataProfilesService
                .createNamedProfile(environmentService.options.profile.name, undefined, workspace)
                .then(async (profile) => {
                await this.updateCurrentProfile(profile);
            })
                .catch((err) => {
                logService.error(err);
            });
        }
    }
};
InjectedUserDataProfileService = __decorate([
    __param(0, IBrowserWorkbenchEnvironmentService),
    __param(1, IUserDataProfilesService),
    __param(2, ILogService)
], InjectedUserDataProfileService);
function getServiceOverride() {
    return {
        [IUserDataProfileService.toString()]: new SyncDescriptor(InjectedUserDataProfileService, [], true),
        [IUserDataProfilesService.toString()]: new SyncDescriptor(BrowserUserDataProfilesService, [], true),
        [IUserDataInitializationService.toString()]: new SyncDescriptor(InjectedUserDataInitializationService, [], true),
        [IUserDataProfileImportExportService.toString()]: new SyncDescriptor(UserDataProfileImportExportService, [], true),
        [IUserDataProfileManagementService.toString()]: new SyncDescriptor(UserDataProfileManagementService, [], true),
        [IUserDataProfileStorageService.toString()]: new SyncDescriptor(UserDataProfileStorageService, [], true),
        [IUserDataSyncUtilService.toString()]: new SyncDescriptor(UserDataSyncUtilService, [], true)
    };
}

export { getServiceOverride as default };
